@@ -1,10 +1,12 @@
 """rxnmapper initialization."""
 __name__ = "rxnmapper"
-__version__ = "0.2.4"  # managed by bump2version
+__version__ = "0.2.7"  # managed by bump2version
 
 
+from .batched_mapper import BatchedMapper
 from .core import RXNMapper
 
 __all__ = [
+    "BatchedMapper",
     "RXNMapper",
 ]
